Object = require "lib/classic"
local push = require "lib/push"
local hotkeys = require "lib/hotkeys"
love.graphics.setDefaultFilter("nearest", "nearest")

FRAME_W, FRAME_H = 320/2, 180/2 --fixed game resolution
local windowWidth, windowHeight = love.window.getDesktopDimensions()
windowWidth, windowHeight = windowWidth*.4, windowHeight*.4 --make the window a bit smaller than the screen itself
push:setupScreen(FRAME_W, FRAME_H, windowWidth, windowHeight, {fullscreen = false})

-- object pool
objects = {}
require "classes/Active"
require "classes/Ball"
require "classes/Paddle"

p_Score = 0
ai_Score = 0

function love.load()
	-- fonts
	debug_font = love.graphics.newFont("assets/fonts/GameText.ttf", 16)
	init_game()
end

function love.update(dt)
	for i, v in ipairs(objects) do
		v:update(dt)
	end
end

function love.draw()
	love.graphics.setFont(debug_font)
	love.graphics.print("dt:"..tostring(love.timer.getDelta()), 4, 0)
	love.graphics.print("fps:"..tostring(love.timer.getFPS()), 4, 12)

	push:start()
	for i, v in ipairs(objects) do
		v:draw()
	end	
	push:finish()
end

function init_game()
	table.insert(objects, Ball(FRAME_W / 2 - 2, FRAME_H / 2 - 2))
	table.insert(objects, Paddle(4, FRAME_H / 2))
end
